#!/usr/bin/env python
from shortcrust import BaseGLApp
from shortcrust.gl2 import *
import sys

from scenes.fader import FaderShader, FaderMesh
from scenes.sphere import SphereScene
from scenes.planet import PlanetScene
from scenes.horizon import HorizonScene
from scenes.pan import PanScene

SOUND_ENABLED = True

if SOUND_ENABLED:
	import pygame

# global constants
FREQ = 44100   # same as audio CD
BITSIZE = -16  # unsigned 16 bit
CHANNELS = 2   # 1 == mono, 2 == stereo
BUFFER = 1024  # audio buffer size in no. of samples
FRAMERATE = 30  # how often to check if playback has finished

MUSIC_BPM = 86.0

BEAT_DURATION = 60.0 / MUSIC_BPM


class RobotDemo(BaseGLApp):
	depthbuffer = True
	fullscreen = True
	title = "Anthem For A New Robot Dawn"

	def setup(self):
		glEnable(GL_BLEND)
		glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA)

		self.fader_shader = FaderShader()
		self.fader_mesh = FaderMesh()

		self.planet_scene = PlanetScene(self)
		self.horizon_scene = HorizonScene(self)
		self.scene = SphereScene(self)
		self.pan_scene = PanScene(self)

		if SOUND_ENABLED:
			try:
				pygame.mixer.init(FREQ, BITSIZE, CHANNELS, BUFFER)
			except pygame.error, exc:
				print >>sys.stderr, "Could not initialize sound system: %s" % exc
				return 1
			#sound = pygame.mixer.Sound('data/beer.mp3')
			#sound.play()
			pygame.mixer.music.load('data/beer.mp3')
			while not pygame.mixer.music.get_busy():
				pygame.mixer.music.play()

	def draw(self, time):
		if SOUND_ENABLED:
			# print repr(pygame.mixer.music.get_busy())
			if not pygame.mixer.music.get_busy():
				self.exit()

			# ignore passed time; use timer from music instead
			time = pygame.mixer.music.get_pos() / 1000.0

		beat = time / BEAT_DURATION
		if beat < 34:
			#self.pan_scene.draw(beat + 56)
			self.planet_scene.draw(beat)
		elif beat < 56:
			self.horizon_scene.draw(beat)
			#self.scene.draw(beat)
		else:
			self.pan_scene.draw(beat)

RobotDemo().run()
