from pygame import image
from shortcrust.gl2 import *


TEXTURE_INDEX_CONSTANTS = [
	GL_TEXTURE0, GL_TEXTURE1, GL_TEXTURE2, GL_TEXTURE3,
	GL_TEXTURE4, GL_TEXTURE5, GL_TEXTURE6, GL_TEXTURE7,
	GL_TEXTURE8, GL_TEXTURE9, GL_TEXTURE10, GL_TEXTURE11,
	GL_TEXTURE12, GL_TEXTURE13, GL_TEXTURE14, GL_TEXTURE15,
	GL_TEXTURE16, GL_TEXTURE17, GL_TEXTURE18, GL_TEXTURE19,
	GL_TEXTURE20, GL_TEXTURE21, GL_TEXTURE22, GL_TEXTURE23,
	GL_TEXTURE24, GL_TEXTURE25, GL_TEXTURE26, GL_TEXTURE27,
	GL_TEXTURE28, GL_TEXTURE29, GL_TEXTURE30, GL_TEXTURE31,
]

next_texture_index = 0


class Texture(object):
	def __init__(self, filename, transparency=False, flipped=True):
		texture_img = image.load(filename)
		pixels = image.tostring(texture_img, 'RGBA' if transparency else 'RGB', flipped)
		self.texture_id = glGenTextures(1)
		# print "texture ID: %s" % self.texture_id
		glBindTexture(GL_TEXTURE_2D, self.texture_id)
		glPixelStorei(GL_UNPACK_ALIGNMENT, 1)
		glTexImage2D(
			GL_TEXTURE_2D, 0, GL_RGBA if transparency else GL_RGB, texture_img.get_width(), texture_img.get_height(), 0,
			GL_RGBA if transparency else GL_RGB, GL_UNSIGNED_BYTE, pixels
		)
		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST)
		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST)

	def activate(self, texture_index=None):
		global next_texture_index

		if texture_index == None:
			texture_index = next_texture_index
			# print "assigned texture index %s" % texture_index
			next_texture_index += 1

		if (texture_index > 31):
			raise ValueError("Texture index out of range")
		glActiveTexture(TEXTURE_INDEX_CONSTANTS[texture_index])
		glBindTexture(GL_TEXTURE_2D, self.texture_id)
		self.texture_index = texture_index
